# SHISHUA for Python: The fastest PRNG

The official page for SHISHUA is [here][SHISHUA].  
This [PyPI][] package provides bindings for Python.

```python
from shishua import SHISHUA
rng = SHISHUA(0)
buffer = rng.random_raw(1 << 30)  # 1 GiB
# It takes 1.5s on my laptop.
```

## API

### `SHISHUA(seed=None)`

Returns a generator instance initialized with the given seed.

The `seed` determines the sequence of numbers that this function returns:

```python
print(SHISHUA('seed').random_raw(10).hex())
#> 1aa64a39f6949b969e97
print(SHISHUA('seed').random_raw(10).hex())
#> 1aa64a39f6949b969e97
print(SHISHUA('different seed, different values').random_raw(10).hex())
#> 216a0889a858eb57ae30
```

The seed can be either:

- A list of four 64-bit integers,
  to map exactly to the functionality provided
  by the underlying SHISHUA algorithm,
- A string, which is hashed into the four integers,
- A single integer, which sets the first of the four,
- If not provided (or undefined),
  a random seed is generated from the system's CSPRNG.

### Associated methods

The object returned by calling `SHISHUA()` also has the following methods,
which all tap into the stream generated by the seed:

- `.random_raw(size)`, which returns a `bytes` filled with random bytes.

[SHISHUA]: https://github.com/espadrine/shishua
[PyPI]: https://pypi.org/project/shishua/
